Skip to main content

Pybible-cli - Bible reference

The pybible-cli is as a basic module for referencing the bible books, chapters and verses. Using the command line is possible to reference the King James Bible (https://www.sacred-texts.com/bib/osrc/index.htm).

Installation

You can install the pybible-cli from PyPI(): pip install pybible-cli

This module is available on Python 3 and above.

How to use

The pybible-cli is a command line application, named pybible. To reference (print on your terminal) verses, chapters, books and even the whole bible simply call the program:

$ pyblible
In the beginning God created the heaven and the earth.
...
The grace of our Lord Jesus Christ be with you all. Amen.

It's possible to reference the whole bible as above or just a part of it, some examples are:

Reference the old testament:

$ pybible -ot
In the beginning God created the heaven and the earth.
...
And he shall turn the heart of the fathers to the children, and the heart of the children to their fathers, lest I come and smite the earth with a curse

Reference the new testament:

$ pybible -nt
The book of the generation of Jesus Christ, the son of David, the son of Abraham.
...
The grace of our Lord Jesus Christ be with you all. Amen.

Reference the book of John:

$ pybible --book john
In the beginning was the Word, and the Word was with God, and the Word was God.
...
And there are also many other things which Jesus did, the which, if they should be written every one, I suppose that even the world itself could not contain the books that should be written. Amen.

Reference third chapter from the book of John:

$ pybible --chapter john 3
There was a man of the Pharisees, named Nicodemus, a ruler of the Jews:
...
He that believeth on the Son hath everlasting life: and he that believeth not the Son shall not see life; but the wrath of God abideth on him.

Reference the fourth verse of the third chapter from the book of John:

$ pybible --verse john 3 4
Nicodemus saith unto him, How can a man be born when he is old? can he enter the second time into his mother's womb, and be born?

It is possible to add extra parameters for adding the reference on the output(-r, --reference) and count the size(-s, --size) of what is been referenced.

For help execute:

$ pybible -h
usage: pybible [-h] [--bible BIBLE]
           [-ot | -nt | --book BOOK_NAME | --chapter BOOK_NAME CHAPTER_NUMBER | --verse BOOK_NAME CHAPTER_NUMBER VERSE_NUMBER]
           [-r] [-s]

Bible reference

optional arguments:
  -h, --help            show this help message and exit
  --bible BIBLE         Bible version to use
  -ot, --old_testament  Reference the old testament
  -nt, --new_testament  Reference the new testament
  --book BOOK_NAME      Reference book
  --chapter BOOK_NAME CHAPTER_NUMBER
                        Reference book and chapter
  --verse BOOK_NAME CHAPTER_NUMBER VERSE_NUMBER
                        Reference book, chapter and verse
  -r, --reference       Include book, chapter number and verse reference
  -s, --size            Size of bible, book, chapter or vere referenced

✞

You can also use pybible-cli on your on python code for referencing the bible, just import pybible_load module from pybible package:

>>> from pybible import pybible_load
>>> bible = pybible_load.load()
>>> bible.name
'King James Bible'

Contributing

If you like this module feel free to contribute and make the pybible-cli module a pythonic bible reference module (that's is the goal).

At this point there is only on bible version available(King James Version), you can help adding more versions of the bible to this module, just follow the OOP structure inside the classes package and pickle it to a single file.

There are some performance issues involving unpickling, you can help on that too ;)

Feel free to reach me for the new features and ideas ...

Metadata

Release files for pybible-cli 1.0.0

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for pybible-cli 1.0.0
File Size Uploaded
pybible-cli-1.0.0.tar.gz 7.0 kB Details

Built distribution (wheel)

Table of built distributions (wheels) for pybible-cli 1.0.0
File Interpreter ABI Platform
pybible_cli-1.0.0-py3-none-any.whl Python 3 none any Details

Total release size: 1.7 MB

Release files / pybible-cli-1.0.0.tar.gz

Download URL pybible-cli-1.0.0.tar.gz
Size 7.0 kB
Tags Source
SHA-256 checksum
How to use checksums
92aa4d885f2d430695e4f23ebda8e411b91aa750d9142a19835fea31d46b492d
BLAKE2b-256 checksum
How to use checksums
84e065339b5618c608d69e8cb59ca268354128f484546a279303963e1d28c779
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/3.1.1 pkginfo/1.5.0.1 requests/2.22.0 setuptools/42.0.2.post20191203 requests-toolbelt/0.9.1 tqdm/4.42.1 CPython/3.7.5

Release files / pybible_cli-1.0.0-py3-none-any.whl

Download URL pybible_cli-1.0.0-py3-none-any.whl
Size 1.7 MB
Tags Python 3
SHA-256 checksum
How to use checksums
7079c18fcf9110196b6faebc63f6fe7b73a9bf031220a1034afb9adf8a8a6b05
BLAKE2b-256 checksum
How to use checksums
2394705b1780f190e70e4e912358e33b084086222e6a8aa512e851fe86e8eb56
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/3.1.1 pkginfo/1.5.0.1 requests/2.22.0 setuptools/42.0.2.post20191203 requests-toolbelt/0.9.1 tqdm/4.42.1 CPython/3.7.5

Release history Release notifications | RSS feed

1.2.5

2 release files

1.2.4

2 release files

1.2.3

2 release files

1.2.2

2 release files

1.2.1

2 release files

1.2.0

2 release files

1.1.4

2 release files

1.1.3

2 release files

1.1.1

2 release files

1.0.1

2 release files

This release

1.0.0 This release

2 release files

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page